#ifndef SVN_VERSION_H
#define SVN_VERSION_H

#define SVN_VERSION "9949cd3c12932b5f3f2997ce460fd959107c65a5 [/startdir/boinc] (archlinux:/build/boinc/src/boinc-nox [makepkg]) [Server-Release: server_release/1.x/1.x.0-3443-g9949cd3c12932b5f3f2997ce460fd959107c65a5]"
#define GIT_REVISION 0x9949cd3c
#define GIT_DATE 1777538602
#define REPOSITORY__STARTDIR_BOINC 1

#endif
